==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebIconButtonDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebButtonBaseDescription } from "./WebButtonBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebIconButtonDescription = /*@__PURE__*/ (() => {
    class WebIconButtonDescription extends WebButtonBaseDescription {
        constructor() {
            super();
            this.af = null;
            this.ae = null;
            this.ac = false;
            this.ag = null;
        }
        get_type() {
            return "WebIconButton";
        }
        get iconName() {
            return this.af;
        }
        set iconName(a) {
            this.af = a;
            this.e("IconName");
        }
        get collection() {
            return this.ae;
        }
        set collection(a) {
            this.ae = a;
            this.e("Collection");
        }
        get mirrored() {
            return this.ac;
        }
        set mirrored(a) {
            this.ac = a;
            this.e("Mirrored");
        }
        get variant() {
            return this.ag;
        }
        set variant(a) {
            this.ag = a;
            this.e("Variant");
        }
    }
    WebIconButtonDescription.$t = /*@__PURE__*/ markType(WebIconButtonDescription, 'WebIconButtonDescription', WebButtonBaseDescription.$);
    return WebIconButtonDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebIconButtonDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebButtonBaseDescription } from "./WebButtonBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebIconButtonDescription = /*@__PURE__*/ (() => {
    class WebIconButtonDescription extends WebButtonBaseDescription {
        get_type() {
            return "WebIconButton";
        }
        constructor() {
            super();
            this.ad = null;
            this.ac = null;
            this.aa = false;
            this.ae = null;
        }
        get iconName() {
            return this.ad;
        }
        set iconName(a) {
            this.ad = a;
            this.g("IconName");
        }
        get collection() {
            return this.ac;
        }
        set collection(a) {
            this.ac = a;
            this.g("Collection");
        }
        get mirrored() {
            return this.aa;
        }
        set mirrored(a) {
            this.aa = a;
            this.g("Mirrored");
        }
        get variant() {
            return this.ae;
        }
        set variant(a) {
            this.ae = a;
            this.g("Variant");
        }
    }
    WebIconButtonDescription.$t = /*@__PURE__*/ markType(WebIconButtonDescription, 'WebIconButtonDescription', WebButtonBaseDescription.$);
    return WebIconButtonDescription;
})();
